@@ -92,7 +92,8 @@ params = {
         'zero_t': 1024,
         'baud':115200,
         'retry_on_comm_failure':1,
-        'verbose': 0
+        'verbose': 0,
+        'disable_torque_on_stop':0
     },
     "wrist_roll": {
         'flip_encoder_polarity': 0,
@@ -123,6 +124,7 @@ params = {
         'zero_t': 2048,
         'baud': 115200,
         'retry_on_comm_failure': 1,
-        'verbose': 0
+        'verbose': 0,
+        'disable_torque_on_stop':1
     }
 }
