@@ -11,6 +11,7 @@ params = {
         'use_group_sync_read': 1,
         'retry_on_comm_failure': 1,
         'baud':115200,
+        'dxl_latency_timer': 64,
         'verbose':0,
         'stow': {
             'arm': 0.0,
@@ -64,6 +65,7 @@ params = {
     },
     "wrist_pitch": {
         'flip_encoder_polarity': 1,
+        'enable_runstop': 1,
         'gr': 1.0,
         'id': 15,
         'max_voltage_limit': 15,
@@ -94,6 +96,7 @@ params = {
     },
     "wrist_roll": {
         'flip_encoder_polarity': 0,
+        'enable_runstop': 1,
         'gr': 1.0,
         'id': 16,
         'max_voltage_limit': 16,
